@@ -2,6 +2,7 @@ import abc
 from drb import AbstractNode
 from requests.auth import AuthBase
 from typing import Optional
+from drb.utils.keyringconnection import kr_get_auth, kr_check
 
 
 class OdataNode(AbstractNode, abc.ABC):
@@ -11,9 +12,10 @@ class OdataNode(AbstractNode, abc.ABC):
 
     def __init__(self, service_url, auth: AuthBase = None):
         super(OdataNode, self).__init__()
+        self._original_service_url = service_url
         self._service_url = service_url.replace('+odata', '') \
             if '+odata' in service_url else service_url
-        self._auth = auth
+        self.__auth = auth
 
     def get_service_url(self) -> str:
         """
@@ -30,7 +32,10 @@ class OdataNode(AbstractNode, abc.ABC):
         :returns: an authentication compatible with requests library.
         :rtype: AuthBase
         """
-        return self._auth
+        if self.__auth is not None:
+            return self.__auth
+        if kr_check(self._original_service_url):
+            return kr_get_auth(self._original_service_url)
 
     @property
     @abc.abstractmethod
